@@ -7,10 +7,10 @@ Saves a single waterfall plot to ``./embers_out/rf_tools``
 """
 
 import argparse
-import pkg_resources
 from pathlib import Path
-from embers.rf_tools.rf_data import single_waterfall
 
+import pkg_resources
+from embers.rf_tools.rf_data import single_waterfall
 
 _parser = argparse.ArgumentParser(
     description="""
@@ -36,7 +36,7 @@ _out_dir = _args.out_dir
 if _rf_file == "":
     print("--------------------------------------------------")
     print("No input data provided, using packaged sample data")
-    print(">>> waterfall --help, for more options")
+    print(">>> waterfall_single --help, for more options")
     print("--------------------------------------------------")
     _rf_file = pkg_resources.resource_filename(
         "embers.kindle", "data/rf_data/S06XX/2019-10-10/S06XX_2019-10-10-02:30.txt"
